@@ -1,16 +1,6 @@
 # -*- coding: utf-8 -*-
 import os
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Dict,
-    Iterable,
-    List,
-    Mapping,
-    Optional,
-    Type,
-    Union,
-)
+from typing import TYPE_CHECKING, Any, Dict, Iterable, List, Mapping, Type, Union
 
 from kiara.exceptions import KiaraProcessingException
 from kiara.models.filesystem import (
@@ -343,11 +333,11 @@ class MergeTableModule(KiaraModule):
 
 class QueryTableSQLModuleConfig(KiaraModuleConfig):
 
-    query: Optional[str] = Field(
+    query: Union[str, None] = Field(
         description="The query to execute. If not specified, the user will be able to provide their own.",
         default=None,
     )
-    relation_name: Optional[str] = Field(
+    relation_name: Union[str, None] = Field(
         description="The name the table is referred to in the sql query. If not specified, the user will be able to provide their own.",
         default="data",
     )
@@ -410,9 +400,9 @@ class QueryTableSQL(KiaraModule):
 
         _table: KiaraTable = inputs.get_value_data("table")
         rel_from_arrow = duckdb.arrow(_table.arrow_table)
-        result: duckdb.DuckDBPyResult = rel_from_arrow.query(_relation_name, _query)
+        result: duckdb.DuckDBPyRelation = rel_from_arrow.query(_relation_name, _query)
 
-        outputs.set_value("query_result", result.fetch_arrow_table())
+        outputs.set_value("query_result", result.arrow())
 
 
 class ExportTableModule(DataExportModule):
@@ -468,9 +458,9 @@ class RenderTableModuleBase(RenderValueModule):
         query = f"""SELECT {', '.join(columnns)} FROM data LIMIT {input_number_of_rows} OFFSET {input_row_offset}"""
 
         rel_from_arrow = duckdb.arrow(arrow_table)
-        query_result: duckdb.DuckDBPyResult = rel_from_arrow.query("data", query)
+        query_result: duckdb.DuckDBPyRelation = rel_from_arrow.query("data", query)
 
-        result_table = query_result.fetch_arrow_table()
+        result_table = query_result.arrow()
         wrap = ArrowTabularWrap(table=result_table)
 
         related_scenes: Dict[str, Union[None, RenderScene]] = {}
